@@ -876,9 +876,9 @@ class LessonbasedGui(Gui):
         response = dlg.run()
         if response == gtk.RESPONSE_OK:
             self.m_t.m_P.header.random_transpose = dlg.get_value()
-            if self.m_t.m_P.header.random_transpose:
+            if self.m_t.m_P.header.random_transpose == True:
                 self.g_random_transpose.set_text(_("Yes"))
-            elif not self.m_t.m_P.header.random_transpose:
+            elif self.m_t.m_P.header.random_transpose == False:
                 self.g_random_transpose.set_text(_("No"))
             else:
                 self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
