@@ -249,9 +249,10 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             ("csound", _("CSound:"), osutils.find_csound_executables()),
             ("mma", "MMA:", osutils.find_mma_executables(
                 cfg.get_list("app/win32_ignore_drives"))),
-            ("lilypond-book", _("Lilypond-book"),
+            ("lilypond-book", _("Lilypond-book:"),
              osutils.find_progs(("lilypond-book", "lilypond-book.py"))),
             ("latex", "Latex:", osutils.find_progs(("latex",))),
+            ("text-editor", "Text editor:", osutils.find_progs(("sensible-editor", "gvim", "gedit", "emacs", "notepad.exe"))),
             ):
             liststore = gtk.ListStore(gobject.TYPE_STRING)
             for p in bins:
@@ -345,7 +346,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
                 cfg.get_string('idtone/tone_%s_ak' % notename)))
         self.g_treeview = gtk.TreeView(self.g_idtone_accels)
         renderer = gtk.CellRendererText()
-        column = gtk.TreeViewColumn(_("Notename"), renderer, text=0)
+        column = gtk.TreeViewColumn(_("Note name"), renderer, text=0)
         self.g_treeview.append_column(column)
         renderer = gtk.CellRendererAccel()
         renderer.set_property('editable', True)
@@ -364,7 +365,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             self.g_idtone_accels.set(it, 1, unichr(accel_key))
             return True
         renderer.connect('accel-edited', acc_ff)
-        column = gtk.TreeViewColumn(_("Key"), renderer, text=1)
+        column = gtk.TreeViewColumn(_i("keyboard|Key"), renderer, text=1)
         self.g_treeview.append_column(column)
         category_vbox.pack_start(self.g_treeview)
         ############
