@@ -49,7 +49,7 @@ _test_mode = False
 
 # The name of the folder containing the standard learning trees.
 # Relative to the installation dir.
-exercises_dir = u"exercises"
+exercises_dir = u"exercises/standard"
 _abs_exercises_dir = os.path.join(os.getcwdu(), exercises_dir) + os.sep
 
 solfege_uri = u"solfege:"
@@ -1538,9 +1538,9 @@ class InfoCache(object):
                 self.parse_file(filename)
             return self._data[filename][field]
         def parse_file(self, filename):
-            from solfege import learningtree
+            from solfege import frontpage 
             try:
-                p = learningtree.load_tree(filename)
+                p = frontpage.load_tree(filename)
                 self._data[filename] = {'title': p.m_name,
                                         'mtime': os.path.getmtime(filename)}
             except Exception, exception:
@@ -1677,10 +1677,10 @@ class LessonFileManager:
         self.m_discards = []
         self.m_uiddb = {}
     def parse(self, debug):
-        lessonpath = [os.path.join('exercises', 'lesson-files'),
+        lessonpath = [os.path.join('exercises', 'standard', 'lesson-files'),
                       filesystem.user_lessonfiles()]
         if debug:
-            lessonpath.append(os.path.join('exercises', 'regression-lesson-files'))
+            lessonpath.append(os.path.join('exercises', 'standard', 'regression-lesson-files'))
         self.m_uiddb = {}
         for dir in lessonpath:
             if not os.path.isdir(dir):
@@ -1809,20 +1809,6 @@ class LessonIdParser(object):
         Return True if the lesson file has a lesson_id.
         """
         return re.search("lesson_id", self.m_file_content) is not None
-    def new_lesson_id(self):
-        """
-        Generate and add a new lesson_id for the file filename.
-        """
-        if self.has_lesson_id():
-            ofile = open(self.m_filename, 'w')
-            m = re.search("lesson_id\s*=\s*\".+?\"", self.m_file_content)
-            ofile.write(self.m_file_content[:m.start()])
-            self.m_new_id = uuid.generate()
-            ofile.write("lesson_id = \"%s\"" % self.m_new_id)
-            ofile.write(self.m_file_content[m.end():])
-            ofile.close()
-        else:
-            self.add_lesson_id()
     def add_header_block(self):
         """
         Add a header block with a lesson id.
